﻿using System.IO;
using System.Windows.Controls;
using System.Windows.Interactivity;
using System.Windows.Media;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Converter;
using Syncfusion.XlsIO;

namespace SilverlightGridSample
{
    public enum ExportAction
    {
        Grid,
        SelectedItems
    }

    public class ExportTriggerAction : TargetedTriggerAction<SfDataGrid>
    {
        public ExportAction ExportAction { get; set; }

        protected override void Invoke(object parameter)
        {
            if (Target == null)
                return;

            var sfd = new SaveFileDialog
            {
                FilterIndex = 1,
                Filter = "Excel 2007 to 2010 Files(*.xlsx)|*.xlsx|Excel 97 to 2003 Files(*.xls)|*.xls"
            };

            if (sfd.ShowDialog() == true)
            {
                var options = new ExcelExportingOptions
                {
                    ExcelVersion = ExcelVersion.Excel2010,
                    ExportingEventHandler = ExportingHandler,
                    CellsExportingEventHandler = CellExportingHandler
                };
                ExcelEngine excelEngine;

                if (ExportAction == ExportAction.Grid)
                    excelEngine = Target.ExportToExcel(Target.View, options);
                //excelEngine = Target.ExportCollectionToExcel(Target.View); 
                else
                {
                    excelEngine = new ExcelEngine();
                    excelEngine.Excel.DefaultVersion = ExcelVersion.Excel2010;
                    var workBook1 = excelEngine.Excel.Workbooks.Create();
                    workBook1.Worksheets.Create();
                    Target.ExportToExcel(Target.SelectedItems, options, workBook1.Worksheets[0]);
                }
                var workBook = excelEngine.Excel.Workbooks[0];
                // Display the dialog. If the user selects a file of the correct format 
                // and clicks Save in the dialog, save the file using the Save method of the Workbook object.

                var stream = sfd.OpenFile();
                workBook.SaveAs(stream);
                stream.Close();
            }
        }

        private void ExportingHandler(object sender, GridExcelExportingEventArgs e)
        {
            switch (e.CellType)
            {
                case ExportCellType.HeaderCell:
                    e.CellStyle.BackGroundBrush = new SolidColorBrush(Colors.Gray);
                    e.CellStyle.ForeGroundBrush = new SolidColorBrush(Colors.White);
                    e.CellStyle.FontInfo.Bold = true;
                    break;
                case ExportCellType.GroupCaptionCell:
                    e.CellStyle.BackGroundBrush = new SolidColorBrush(Colors.LightGray);
                    e.CellStyle.ForeGroundBrush = new SolidColorBrush(Colors.Orange);
                    break;
                case ExportCellType.GroupSummaryCell:
                    e.CellStyle.BackGroundBrush = new SolidColorBrush(Colors.LightGray);
                    break;
            }
            e.CellStyle.FontInfo.Size = 12;
            e.CellStyle.FontInfo.FontName = "Segoe UI";
        }

        private void CellExportingHandler(object sender, GridCellExcelExportingEventArgs e)
        {
            e.Range.CellStyle.Font.Size = 12;
            e.Range.CellStyle.Font.FontName = "Segoe UI";
        }
    }
}
