﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace SilverlightGridSample
{
    public class ViewModel : INotifyPropertyChanged
    {
        EmployeeDetails emp = new EmployeeDetails();

        public ViewModel()
        {
            this.DataSource = emp;

        }

        private ObservableCollection<BusinessObjects> source;

        public ObservableCollection<BusinessObjects> DataSource
        {
            get { return source; }
            set
            {
                source = value;
                OnPropertyChanged("DataSource");
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion
    }

    public class EmployeeDetails : ObservableCollection<BusinessObjects>
    {
        Random rand = new Random();

        public EmployeeDetails()
        {
            PopulateCollection();
        }

        private void PopulateCollection()
        {
            Clear();

            var customer = new Customer {CustomerID = 1, CustomerName = "SyncFusion"};

            var b = new BusinessObjects() {FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "High", CreatedBy = "peter", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 200, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "Joseph", Private = "False"};
            Add(b);
            b = new BusinessObjects() {SequenceNum = 300, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "Masd", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 400, FormattedCreatedDate = null, PriorityTypeAsString = "High", CreatedBy = "john", Private = "False" };
            var order = new Order {CreatedDate = DateTime.Now, CustomerID = 1, Customer = customer};
            b.Orders = new List<Order> {order};
            Add(b);

            b = new BusinessObjects() {SequenceNum = 500, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "mads", Private = "False" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 600, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "High", CreatedBy = "Robert", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 700, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "Jods", Private = "False" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 800, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "High", CreatedBy = "Silert", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 900, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "Jods", Private = "False" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 1000, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "High", CreatedBy = "verg", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 1100, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "david", Private = "False" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 1200, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "High", CreatedBy = "daniel", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 1300, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "elisabeth", Private = "False" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 1400, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "High", CreatedBy = "edvin", Private = "True" };
            Add(b);
            b = new BusinessObjects() {SequenceNum = 1500, FormattedCreatedDate = DateTime.Now, PriorityTypeAsString = "Low", CreatedBy = "vinoth", Private = "False" };
            Add(b);
        }
    }

    public class Customer : INotifyPropertyChanged
    {
        private int _customerID;
        private string _customerName;
        private DateTime? _createdDate;

        public int CustomerID
        {
            get { return _customerID; }
            set
            {
                _customerID = value;
                OnPropertyChanged("CustomerID");
            }
        }

        public string CustomerName
        {
            get { return _customerName; }
            set { _customerName = value;
                OnPropertyChanged("CustomerName"); }
        }

        public DateTime? CreatedDate
        {
            get { return _createdDate; }
            set { _createdDate = value;
                OnPropertyChanged("CreatedDate");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

    }

    public class Order : INotifyPropertyChanged
    {
        private int _customerID;
        private string _customerName;
        private DateTime? _createdDate;
        private int _orderID;
        private Customer _customer;

        public int OrderID
        {
            get { return _orderID; }
            set { _orderID = value; OnPropertyChanged("OrderID"); }
        }

        public int CustomerID
        {
            get { return _customerID; }
            set
            {
                _customerID = value;
                OnPropertyChanged("CustomerID");
            }
        }

        public Customer Customer
        {
            get { return _customer; }
            set { _customer = value; }
        }

        public DateTime? CreatedDate
        {
            get { return _createdDate; }
            set
            {
                _createdDate = value;
                OnPropertyChanged("CreatedDate");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
    public class BusinessObjects : INotifyPropertyChanged
    {
        private int? _sno;

        public int? SequenceNum
        {
            get { return _sno; }
            set
            {
                _sno = value;
                OnPropertyChanged("SequenceNum");
            }
        }

        private string _createdby;

        public string CreatedBy
        {
            get { return _createdby; }
            set
            {
                _createdby = value;
                OnPropertyChanged("CreatedBy");
            }
        }

        private DateTime? date;

        public DateTime? FormattedCreatedDate
        {
            get { return date; }
            set
            {
                date = value;
                OnPropertyChanged("FormattedCreatedDate");
            }
        }

        public List<Order> Orders { get; set; }

        public Customer LinkCustomer
        {
            get
            {
                var order = Orders?.FirstOrDefault();
                return order?.Customer;
            }
        }

        private string prioritytype;

        public string PriorityTypeAsString
        {
            get { return prioritytype; }
            set
            {
                prioritytype = value;
                OnPropertyChanged("PriorityTypeAsString");
            }
        }

        private string pv;
        private Customer _customer;

        public string Private
        {
            get { return pv; }
            set
            {
                pv = value;
                OnPropertyChanged("Private");
            }
        }

        public bool Test1 { get; set; }
        public bool Test2 { get; set; }
        public bool Test3 { get; set; }

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
    

